@@ -1,7 +1,7 @@
 package Test::Perinci::CmdLine;
 
-our $DATE = '2015-11-27'; # DATE
-our $VERSION = '1.29'; # VERSION
+our $DATE = '2015-11-28'; # DATE
+our $VERSION = '1.30'; # VERSION
 
 use 5.010001;
 use strict;
@@ -565,6 +565,15 @@ sub square { my %args=@_; [200, "OK", $args{num}**2] }
                         exit_code      => 0,
                         stdout_like    => qr/^\[\s*"?200"?,\s*"OK",\s*\[\s*"a",\s*"b"\s*\],\s*\{.*\}\s*\]/s,
                     },
+
+                    {
+                        name           => 'can handle function which returns naked result',
+                        gen_args       => {url => '/Perinci/Examples/Tiny/hello_naked'},
+                        inline_gen_args => {load_module=>['Perinci::Examples::Tiny']},
+                        argv           => [],
+                        exit_code      => 0,
+                        stdout_like    => qr/Hello, world/,
+                    },
                 ],
             }, # call action
 
@@ -1359,7 +1368,7 @@ Test::Perinci::CmdLine - Common test suite for Perinci::CmdLine::{Lite,Classic,I
 
 =head1 VERSION
 
-This document describes version 1.29 of Test::Perinci::CmdLine (from Perl distribution Test-Perinci-CmdLine), released on 2015-11-27.
+This document describes version 1.30 of Test::Perinci::CmdLine (from Perl distribution Test-Perinci-CmdLine), released on 2015-11-28.
 
 =head1 SEE ALSO
 
